@@ -54,7 +54,8 @@
 #' when filter is TRUE. (default "haar") Passed to \code{link[waveslim]{wave.filter}}.
 #' @param j single numeric, the level to which to smooth. Passed to \code{link[waveslim]{wave.filter}} (default 8).
 #' @param penalty single characgter, the penalty to use for changepoint detection. default ("SIC").
-#' @param pen.value Value of the type 1 error required when penalty is "Asymptotic".
+#' @param pen.value1 Value of the type 1 error required when penalty is "Asymptotic".
+#' @param pen.value2 Default set as NULL and so equals pen.value1 if no input. 
 #' @param intervalseconds An integer number of seconds between 5 and 30 during which at most one changepoint may occur.
 #' @param plot.it single logical, Creates a plot showing the zero crossings counted by the step counting algorithm#' @param Centre Centres the xz signal about 0 when set to True.
 #' @param mininterval single numeric that defines the smallest changepoint initially found. Passed to \code{\link[changepoint]{cpt.var}} as the variable minseglen
@@ -88,6 +89,8 @@
 #' @param ma.smooth Should a moving average filter be applied to the data. 
 #' @param Peak_Threshold Number of values either side of the peak/valley that are higher/lower for the value to qualify as a peak/valley 
 #' @param Step_Threshold The difference between a peak, valley then peak or valley, peak then valley to constitute a step.
+#' @param sd_Threshold A Threshold used to determine when to calculate steps based on the standard deviation between potential steps. If the standard deviation is above this threshold then the algorithm does not calculate steps.
+#' @param magsa_Threshold A Threshold used to determine when to calculate steps based on the mean magnitude of acceleration of a segmentd. If the mean magnitude of the segment is below this threshold then the algorithm does not calculate steps.
 #' @param verbose single logical should additional progress reporting be printed at the console? (default TRUE).
 #' @param ... other arguments to be passed to \code{\link{dataImport}},
 #' \code{\link{segmentation}} and other functions with these functions.
@@ -120,17 +123,22 @@ getGENEAsegments <- function(testfile,
                              # Changepoint variables 
                              changepoint = c("UpDownDegrees", "TempFreq", "UpDownFreq", 
                                              "UpDownMean", "UpDownVar", "UpDownMeanVar",
-                                             "DegreesMean", "DegreesVar", "DegreesMeanVar"), 
+                                             "DegreesMean", "DegreesVar", "DegreesMeanVar", 
+                                             "UpDownMeanVarDegreesMeanVar", 
+                                             "UpDownMeanVarMagMeanVar"),
                              penalty = "Manual",
-                             pen.value = 10,
+                             pen.value1 = 40,
+                             pen.value2 = 400,
                              intervalseconds = 30,
                              mininterval = 5,
                              # Step Coutner 2 variables 
                              peaks = TRUE,
                              AxesMethod = c("X","Y","Z","XZ","XY","YZ","XYZ"), 
                              ma.smooth = TRUE,
-                             Peak_Threshold = 10, 
+                             Peak_Threshold = 3, 
                              Step_Threshold = 0.5,
+                             sd_Threshold = 150,
+                             magsa_Threshold = 0.15,
                              # Step Counter 1 Variables
                              stepmethod = c("Chebyfilter","Butterfilter","longrun","none"),
                              boundaries = c(0.15, 1.0), 
@@ -148,12 +156,15 @@ getGENEAsegments <- function(testfile,
                              verbose = FALSE,
                              ...) {
 
+  #### Error Catching ####
     if (!(length(verbose) == 1 && is.logical(verbose))) { stop("verbose should be a single logical") }
 
     # Ensure variables are being passed correctly
     if (missing(stepmethod)) {stepmethod = "Chebyfilter"} # Set Chebyfilter as the default.
     if (missing(AxesMethod)) {AxesMethod = "XZ"}
-    if (missing(changepoint)) {changepoint = "UpDownDegrees"}
+    if (missing(changepoint)) {changepoint = "UpDownMeanVarDegreesMeanVar"}
+    if (is.null(pen.value2)) {pen.value2 = pen.value1}
+  
     # files should exist
 
     info <- file.info(testfile)
@@ -220,7 +231,7 @@ getGENEAsegments <- function(testfile,
         stop("outputdir should be a single character") }
 
 
-    # check datacols
+    #### check datacols ####
 
     if (identical(datacols, "default")) {
       
@@ -298,7 +309,7 @@ getGENEAsegments <- function(testfile,
             outName <- paste0(shortName, outputtoken)
 
             
-            # perform segmentation
+            #### perform segmentation ####
             segData <- try(segmentation(data = inDat,
                                         outputfile = outName,
                                         outputdir = outputdir,
@@ -309,7 +320,8 @@ getGENEAsegments <- function(testfile,
                                         j = j, 
                                         changepoint = changepoint,
                                         penalty = penalty,
-                                        pen.value = pen.value,
+                                        pen.value1 = pen.value1,
+                                        pen.value2 = pen.value2,
                                         intervalseconds = intervalseconds,
                                         mininterval = mininterval,
                                         peaks = peaks,
@@ -317,6 +329,8 @@ getGENEAsegments <- function(testfile,
                                         ma.smooth = ma.smooth,
                                         Peak_Threshold = Peak_Threshold, 
                                         Step_Threshold = Step_Threshold,
+                                        sd_Threshold = sd_Threshold,
+                                        magsa_Threshold = magsa_Threshold,
                                         stepmethod = stepmethod,  
                                         boundaries= boundaries,
                                         samplefreq = samplefreq,
@@ -347,6 +361,7 @@ getGENEAsegments <- function(testfile,
 
         output[[ff]] <- segData
         
+        #### Plot Changepoints ####
         if (plot.seg == TRUE){
           AccData = read.bin(ff, start = start, end = end, ...)
           tmp2 = get.intervals(AccData, start = 0, end = 1, incl.date = T)
